==> un-applet_1.3.2_all.tar.bz2: un-applet_1.3.2_all/usr/share/un-applet/un-applet-system-settings.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
###############################################################################
# update-notifier-applet
# copyright (c) 2015-2016 Michael Lange <klappnase@tuxfamily.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the #hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################

import sys
import os
import gettext

INSTALLDIR = os.path.abspath(sys.path[0])
ICONDIR = os.path.join(INSTALLDIR, 'icons')

# install gettext first
if INSTALLDIR.startswith('/usr/local'):
    localepath = '/usr/local/share/locale'
elif INSTALLDIR.startswith('/usr'):
    localepath = '/usr/share/locale'
else:
    localepath = os.path.join(INSTALLDIR, 'locale')
gettext.install('un-applet', localepath, unicode=1)

import signal
import Tkinter
Tkinter.wantobjects = 0
import ttk
from tkMessageBox import showinfo, showerror

import ConfigHandler
ConfigHandler.initialize()
from BaseDialog import BaseDialog
from Icon import Icon
from Counter import Counter
from UnicodeHandler import fsdecode

###############################################################################

class SysConfigDialog(BaseDialog):
    def __init__(self, *args, **kw):
        BaseDialog.__init__(self, *args, **kw)
        self.config_handler = ConfigHandler.SysConfigHandler()

        self.dist_upgrade = Tkinter.StringVar(value=self.config_handler.get('DIST_UPGRADE'))
        self.need_applet = Tkinter.StringVar(value=self.config_handler.get('NEED_APPLET'))
        self.verify_mirrors = Tkinter.StringVar(value=self.config_handler.get('VERIFY_MIRRORS'))
        self.notify_holds = Tkinter.StringVar(value=self.config_handler.get('NOTIFY_HOLDS'))
        self.notify_new = Tkinter.StringVar(value=self.config_handler.get('NOTIFY_NEW'))
        self.pm_program = Tkinter.StringVar(value=self.config_handler.get('PM_PROGRAM'))

        self.grid_columnconfigure(1, weight=1)

        self.img = Icon('preferences')
        self.icon = Tkinter.Label(self, image=self.img)
        self.icon.grid(row=0, column=0, rowspan=2, padx=10, pady=10, sticky='w')

        self.msg = Tkinter.Label(self, font='TkCaptionFont',
                                    text=_('un-applet System Settings'), anchor='w')
        self.msg.grid(row=0, column=1, padx=10, pady=(10, 3), sticky='w')
        self.detail = Tkinter.Label(self, justify='left',
                text=_('Configure the periodic search for pending updates') +\
                     u'\n' + _('and the upgrade procedure.'))
        self.detail.grid(row=1, column=1, padx=10, pady=(3, 10), sticky='w')

        self.frame = Tkinter.Frame(self, relief='groove', bd=2)
        self.frame.grid(row=2, column=0, columnspan=2, padx=5, pady=5, sticky='news')
        self.frame.grid_columnconfigure(2, weight=1)

        Tkinter.Label(self.frame, text=_('Package management program:'), anchor='w').grid(
                        row=0, column=0, padx=10, pady=(15,10), sticky='w')
        ttk.Radiobutton(self.frame, text='apt-get',
                        variable=self.pm_program, value='"apt-get"').grid(
                        row=0, column=1, padx=10, pady=(15,10), sticky='w')
        ttk.Radiobutton(self.frame, text='aptitude',
                        variable=self.pm_program, value='"aptitude"').grid(
                        row=0, column=2, padx=(20,10), pady=(15,10), sticky='w')

        Tkinter.Label(self.frame, text=_('Upgrade method:'), anchor='w').grid(
                        row=1, column=0, padx=10, pady=(0,10), sticky='w')
        ttk.Radiobutton(self.frame, text=_('Complete'),
                        variable=self.dist_upgrade, value='"1"').grid(
                        row=1, column=1, padx=10, pady=(0,10), sticky='w')
        ttk.Radiobutton(self.frame, text=_('Safe'),
                        variable=self.dist_upgrade, value='"0"').grid(
                        row=1, column=2, padx=(20,10), pady=(0,10), sticky='w')

        self.update_interval = Counter(self.frame,
            label=_('Min. time interval between automatic updates of the package database:'),
            label2=_('hours'), width=6, from_=1, to=200, increment=1,
            value=self._secs2hrs(self.config_handler.get('UPDATE_INTERVAL')))
        self.update_interval.grid(
            row=2, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.need_applet,
            text=_('Only search for updates when an un-applet instance is running') +\
            u' ' + _('(recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=3, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.verify_mirrors,
            text=_('Verify mirror server reachability before searching for updates') +\
            u' ' + _('(recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=4, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.notify_holds,
            text=_('Notify about updates for packages put on "hold"') +\
            u' ' + _('(not recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=5, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.notify_new,
            text=_('Notify about new packages that will be installed') +\
            u' ' + _('(not recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=6, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        buttonbox = Tkinter.Frame(self, relief='flat', bd=0)
        buttonbox.grid(row=3, column=0, columnspan=2, sticky='ew')
        buttonbox.grid_columnconfigure(0, weight=1)
        buttonbox.grid_columnconfigure(1, weight=1)
        self.applybutton = ttk.Button(buttonbox, text=_('Apply'),
                                        command=self.apply, state='disabled')
        self.applybutton.grid(row=0, column=0, pady=8, padx=15, sticky='e')
        self.cancelbutton = ttk.Button(buttonbox, text=_('Close'), command=self.hide)
        self.cancelbutton.grid(row=0, column=1, pady=8, padx=15, sticky='w')
        self.assign_hotkey(self.applybutton)
        self.assign_hotkey(self.cancelbutton)

        fname, e, r, w = self.config_handler.permissions()
        if not r:
            msg = _('No read access to file') + u' ' + fsdecode(fname)+ u' .\n' +\
                      _('Please try again with administrator privilege.')
            showerror(title='Update Notifier Applet', message=_('Error'),
                        detail=msg)
            self.hide()

        if not w:
            msg = _('No write access to file') + u' ' + fsdecode(fname)+ u' .\n' +\
                  _('You may view the settings but will not be able to apply changes.')
            showinfo(title='Update Notifier Applet', message=_('Please note:'),
                        detail=msg)

        for var in (self.dist_upgrade, self.need_applet, self.notify_holds,
                    self.notify_new, self.pm_program, self.verify_mirrors,
                    self.update_interval):
            var.trace('w', self.track_changes)

    def _hrs2secs(self, hrs):
        return(hrs * 3600 - 300)

    def _secs2hrs(self, secs):
        if secs % 3600:
            return(secs / 3600 + 1)
        else:
            return(secs / 3600)

    def apply(self):
        fname, e, r, w = self.config_handler.permissions()
        if not w:
            msg = _('No write access to file') + u' ' + fsdecode(fname)+ u' .\n' +\
                _('Please try again with administrator privilege.')
            return showerror(title='Update Notifier Applet',
                                message=_('Error'), detail=msg)

        ok = True
        try:
            if not 1 <= self.update_interval.get() <= 200:
                ok = False
        except ValueError:
            ok = False
        if not ok:
            self.update_interval.focus_set()
            self.update_interval.selection('clear')
            self.update_interval.selection('range', 0, 'end')
            msg = _('Please choose an integer value between %d and %d') % (1, 200)
            return showerror(title='Update Notifier Applet',
                                message=_('Error'), detail=msg)

        self.config_handler.set('UPDATE_INTERVAL', self._hrs2secs(self.update_interval.get()))
        self.config_handler.set('DIST_UPGRADE', self.dist_upgrade.get())
        self.config_handler.set('NEED_APPLET', self.need_applet.get())
        self.config_handler.set('VERIFY_MIRRORS', self.verify_mirrors.get())
        self.config_handler.set('NOTIFY_HOLDS', self.notify_holds.get())
        self.config_handler.set('NOTIFY_NEW', self.notify_new.get())
        self.config_handler.set('PM_PROGRAM', self.pm_program.get())

        if not self.config_handler.save():
            msg = _('Error while trying to write file') + u' ' + fsdecode(fname)+ u' .\n'
            return showerror(title='Update Notifier Applet',
                                message=_('Error'), detail=msg)
        msg = _('Please note:') + u'\n' + _('the new settings will take effect immediately') +\
              u'.\n' + _("However until the next update of the package database") + \
              u' ' + _("the applet's list of upgradable packages") + u' ' +\
              _('may no longer accurately reflect the packages that will be installed during an upgrade.')
        self.track_changes()
        showinfo(title='Update Notifier Applet',
                 message=_('The new settings have been stored'), detail=msg)

    def hide(self, *args):
        self.quit()

    def settings_changed(self):
        if self.dist_upgrade.get() != self.config_handler.get('DIST_UPGRADE'):
            return(True)
        if self.need_applet.get() != self.config_handler.get('NEED_APPLET'):
            return(True)
        if self.notify_holds.get() != self.config_handler.get('NOTIFY_HOLDS'):
            return(True)
        if self.notify_new.get() != self.config_handler.get('NOTIFY_NEW'):
            return(True)
        if self.pm_program.get() != self.config_handler.get('PM_PROGRAM'):
            return(True)
        if self.verify_mirrors.get() != self.config_handler.get('VERIFY_MIRRORS'):
            return(True)
        if self._hrs2secs(self.update_interval.get()) != self.config_handler.get('UPDATE_INTERVAL'):
            return(True)
        return(False)

    def track_changes(self, *args):
        if self.settings_changed():
            self.applybutton.configure(state='normal')
        else:
            self.applybutton.configure(state='disabled')

###############################################################################

def main():
    root = Tkinter.Tk()
    root.withdraw()
    if Tkinter.TkVersion < 8.6:
        try:
            tkimgver = root.tk.call('package', 'require', 'img::png')
        except Tkinter.TclError:
            msg = _('No PNG image support available, aborting.') + u'\n' +\
                  _('Please install the tk image library') + u'\n(apt-get install libtk-img).'
            showerror(title='Update Notifier Applet', message=_('Error'),
                        detail=msg)
            root.quit()
            sys.exit()

    try:
        root.iconimg = Tkinter.PhotoImage(file=os.path.join(ICONDIR, 'un-applet.png'))
        root.tk.call('wm', 'iconphoto', '.', '-default', root.iconimg)
    except:
        pass

    def on_return(event):
        event.widget.event_generate('<space>')
    root.bind_class('TButton', '<Return>', on_return)
    root.bind_class('TCheckbutton', '<Return>', on_return)
    root.bind_class('TRadiobutton', '<Return>', on_return)
    try:
        ttk.Style().theme_use('alt')
    except:
        pass

    app = SysConfigDialog(root)

    root.protocol('WM_DELETE_WINDOW', app.hide)
    for signum in (2, 3, 15):
        signal.signal(signum, app.hide)

    def poll_signal():
        root.after(500, poll_signal)
    poll_signal()

    root.update_idletasks()
    app.show()
    root.mainloop()
    root.destroy()

if __name__ == '__main__':
    main()

==> un-applet_1.4_all.tar.bz2: un-applet_1.4_all/usr/share/un-applet/un-applet-system-settings.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
###############################################################################
# un-applet
# copyright (c) 2015-2016 Michael Lange <klappnase@tuxfamily.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the #hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################

import libmisc
libmisc.install_gettext()

import ConfigHandler
ConfigHandler.initialize()

import os
import sys
import Tkinter
import ttk
from tkMessageBox import showinfo, showerror

from BaseDialog import BaseDialog
from Counter import Counter
from Icon import Icon
from UnicodeHandler import fsdecode

###############################################################################

class SysConfigDialog(BaseDialog):
    def __init__(self, master=None, **kw):
        BaseDialog.__init__(self, master,
            buttons=(_('Apply'), _('Close')), icon='preferences',
            message=_('un-applet System Settings'),
            detail=_('Configure the periodic search for pending updates') +\
                        u'\n' + _('and the upgrade procedure.'), **kw)

        self.config_handler = ConfigHandler.SysConfigHandler()

        self.dist_upgrade = Tkinter.StringVar(value=self.config_handler.get('DIST_UPGRADE'))
        self.need_applet = Tkinter.StringVar(value=self.config_handler.get('NEED_APPLET'))
        self.verify_mirrors = Tkinter.StringVar(value=self.config_handler.get('VERIFY_MIRRORS'))
        self.notify_holds = Tkinter.StringVar(value=self.config_handler.get('NOTIFY_HOLDS'))
        self.notify_new = Tkinter.StringVar(value=self.config_handler.get('NOTIFY_NEW'))
        self.pm_program = Tkinter.StringVar(value=self.config_handler.get('PM_PROGRAM'))

        self.frame.configure(relief='groove', bd=2)
        self.frame.grid_configure(padx=5, pady=5)
        self.frame.grid_columnconfigure(2, weight=1)

        Tkinter.Label(self.frame, text=_('Package management program:'), anchor='w').grid(
                        row=0, column=0, padx=10, pady=(15,10), sticky='w')
        ttk.Radiobutton(self.frame, text='apt-get',
                        variable=self.pm_program, value='"apt-get"').grid(
                        row=0, column=1, padx=10, pady=(15,10), sticky='w')
        ttk.Radiobutton(self.frame, text='aptitude',
                        variable=self.pm_program, value='"aptitude"').grid(
                        row=0, column=2, padx=(20,10), pady=(15,10), sticky='w')

        Tkinter.Label(self.frame, text=_('Upgrade method:'), anchor='w').grid(
                        row=1, column=0, padx=10, pady=(0,10), sticky='w')
        ttk.Radiobutton(self.frame, text=_('Complete'),
                        variable=self.dist_upgrade, value='"1"').grid(
                        row=1, column=1, padx=10, pady=(0,10), sticky='w')
        ttk.Radiobutton(self.frame, text=_('Safe'),
                        variable=self.dist_upgrade, value='"0"').grid(
                        row=1, column=2, padx=(20,10), pady=(0,10), sticky='w')

        self.update_interval = Counter(self.frame,
            label=_('Min. time interval between automatic updates of the package database:'),
            rlabel=_('hours'), width=6, from_=1, to=200, increment=1,
            value=self._secs2hrs(self.config_handler.get('UPDATE_INTERVAL')))
        self.update_interval.grid(
            row=2, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.need_applet,
            text=_('Only search for updates when an un-applet instance is running') +\
            u' ' + _('(recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=3, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.verify_mirrors,
            text=_('Verify mirror server reachability before searching for updates') +\
            u' ' + _('(recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=4, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.notify_holds,
            text=_('Notify about updates for packages put on "hold"') +\
            u' ' + _('(not recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=5, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        ttk.Checkbutton(self.frame, variable=self.notify_new,
            text=_('Notify about new packages that will be installed') +\
            u' ' + _('(not recommended)'), onvalue='"1"', offvalue='"0"').grid(
            row=6, column=0, columnspan=3, padx=10, pady=10, sticky='w')

        self.buttons()[0].configure(command=self.apply, state='disabled')
        self.buttons()[1].configure(command=self.hide)
        self.assign_hotkeys()

        fname, e, r, w = self.config_handler.permissions()
        if not r:
            msg = _('No read access to file') + u' ' + fsdecode(fname)+ u' .\n' +\
                      _('Please try again with administrator privilege.')
            showerror(title='Update Notifier Applet', message=_('Error'),
                        detail=msg)
            self.hide()

        if not w:
            msg = _('No write access to file') + u' ' + fsdecode(fname)+ u' .\n' +\
                  _('You may view the settings but will not be able to apply changes.')
            showinfo(title='Update Notifier Applet', message=_('Please note:'),
                        detail=msg)

        for var in (self.dist_upgrade, self.need_applet, self.notify_holds,
                    self.notify_new, self.pm_program, self.verify_mirrors,
                    self.update_interval):
            var.trace('w', self.track_changes)

    def _hrs2secs(self, hrs):
        return(hrs * 3600 - 300)

    def _secs2hrs(self, secs):
        if secs % 3600:
            return(secs / 3600 + 1)
        else:
            return(secs / 3600)

    def apply(self):
        fname, e, r, w = self.config_handler.permissions()
        if not w:
            msg = _('No write access to file') + u' ' + fsdecode(fname)+ u' .\n' +\
                _('Please try again with administrator privilege.')
            return showerror(title='Update Notifier Applet',
                                message=_('Error'), detail=msg)

        ok = True
        try:
            if not 1 <= self.update_interval.get() <= 200:
                ok = False
        except ValueError:
            ok = False
        if not ok:
            self.update_interval.focus_set()
            self.update_interval.selection('clear')
            self.update_interval.selection('range', 0, 'end')
            msg = _('Please choose an integer value between %d and %d') % (1, 200)
            return showerror(title='Update Notifier Applet',
                                message=_('Error'), detail=msg)

        self.config_handler.set('UPDATE_INTERVAL', self._hrs2secs(self.update_interval.get()))
        self.config_handler.set('DIST_UPGRADE', self.dist_upgrade.get())
        self.config_handler.set('NEED_APPLET', self.need_applet.get())
        self.config_handler.set('VERIFY_MIRRORS', self.verify_mirrors.get())
        self.config_handler.set('NOTIFY_HOLDS', self.notify_holds.get())
        self.config_handler.set('NOTIFY_NEW', self.notify_new.get())
        self.config_handler.set('PM_PROGRAM', self.pm_program.get())

        if not self.config_handler.save():
            msg = _('Error while trying to write file') + u' ' + fsdecode(fname)+ u' .\n'
            return showerror(title='Update Notifier Applet',
                                message=_('Error'), detail=msg)
        msg = _('Please note:') + u'\n' + _('the new settings will take effect immediately') +\
              u'.\n' + _("However until the next update of the package database") + \
              u' ' + _("the applet's list of upgradable packages") + u' ' +\
              _('may no longer accurately reflect the packages that will be installed during an upgrade.')
        self.track_changes()
        showinfo(title='Update Notifier Applet',
                 message=_('The new settings have been stored'), detail=msg)

    def hide(self, *args):
        self.quit()

    def settings_changed(self):
        if self.dist_upgrade.get() != self.config_handler.get('DIST_UPGRADE'):
            return(True)
        if self.need_applet.get() != self.config_handler.get('NEED_APPLET'):
            return(True)
        if self.notify_holds.get() != self.config_handler.get('NOTIFY_HOLDS'):
            return(True)
        if self.notify_new.get() != self.config_handler.get('NOTIFY_NEW'):
            return(True)
        if self.pm_program.get() != self.config_handler.get('PM_PROGRAM'):
            return(True)
        if self.verify_mirrors.get() != self.config_handler.get('VERIFY_MIRRORS'):
            return(True)
        if self._hrs2secs(self.update_interval.get()) != self.config_handler.get('UPDATE_INTERVAL'):
            return(True)
        return(False)

    def track_changes(self, *args):
        if self.settings_changed():
            self.buttons()[0].configure(state='normal')
        else:
            self.buttons()[0].configure(state='disabled')

###############################################################################

def main():
    root = libmisc.mainwindow()
    app = SysConfigDialog(root)

    root.quit_command(app.hide)

    root.update_idletasks()
    app.show()
    root.mainloop()
    root.destroy()

if __name__ == '__main__':
    main()
